@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -61,11 +61,11 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <QFormLayout>
 #include <QGroupBox>
 #include <QLabel>
+#include <QMenu>
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QVBoxLayout>
 #include <QWhatsThis>
-#include <kwidgetsaddons_version.h>
 
 using KMime::DateFormatter;
 using namespace MailCommon;
@@ -947,9 +947,11 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     mTagListBox = new QListWidget(mTagsGroupBox);
     mTagListBox->setDragDropMode(QAbstractItemView::InternalMove);
     connect(mTagListBox->model(), &QAbstractItemModel::rowsMoved, this, &AppearancePageMessageTagTab::slotRowsMoved);
+    connect(mTagListBox, &QListWidget::customContextMenuRequested, this, &AppearancePageMessageTagTab::slotCustomMenuRequested);
 
     mTagListBox->setMinimumWidth(150);
     listboxgrid->addWidget(mTagListBox);
+    mTagListBox->setContextMenuPolicy(Qt::CustomContextMenu);
 
     // RHS for individual tag settings
 
@@ -1003,6 +1005,16 @@ void AppearancePageMessageTagTab::slotEmitChangeCheck()
     slotEmitChanged();
 }
 
+void AppearancePageMessageTagTab::slotCustomMenuRequested(const QPoint &)
+{
+    const int currentIndex = mTagListBox->currentRow();
+    if (currentIndex >= 0) {
+        QMenu menu(this);
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete"), this, &AppearancePageMessageTagTab::slotRemoveTag);
+        menu.exec(QCursor::pos());
+    }
+}
+
 void AppearancePageMessageTagTab::slotRowsMoved(const QModelIndex &, int sourcestart, int sourceEnd, const QModelIndex &, int destinationRow)
 {
     Q_UNUSED(sourceEnd)
@@ -1126,13 +1138,8 @@ void AppearancePageMessageTagTab::slotRemoveTag()
 {
     const int tmp_index = mTagListBox->currentRow();
     if (tmp_index >= 0) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::ButtonCode::PrimaryAction
             == KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::Yes
-            == KMessageBox::questionYesNo(this,
-#endif
                                                i18n("Do you want to remove tag \'%1\'?", mTagListBox->item(mTagListBox->currentRow())->text()),
                                                i18nc("@title:window", "Remove Tag"),
                                                KStandardGuiItem::remove(),
