@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -23,7 +23,7 @@ namespace TemplateParser
 class CustomTemplates;
 class TemplatesConfiguration;
 }
-namespace PimCommonAutoCorrection
+namespace TextAutoCorrection
 {
 class AutoCorrectionWidget;
 }
@@ -211,7 +211,7 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    PimCommonAutoCorrection::AutoCorrectionWidget *autocorrectionWidget = nullptr;
+    TextAutoCorrection::AutoCorrectionWidget *autocorrectionWidget = nullptr;
 };
 
 class ComposerPageAutoImageResizeTab : public ConfigModuleTab
